dot-assert_tigris_available: Helper function simply asserts if tigris is installed. It is...

.assert_tigris_availableR Documentation

Helper function simply asserts if tigris is installed. It is not required, to run the package in general, but is required for some additional functionality

Description

Helper function simply asserts if tigris is installed. It is not required, to run the package in general, but is required for some additional functionality

Usage

.assert_tigris_available(fn_name)

Arguments

fn_name

Character scalar naming the calling function, used in the error message.

Value

Invisibly returns NULL; otherwise throws an error when tigris is unavailable.


gsClusterDetect documentation built on July 27, 2026, 5:09 p.m.