dot-clean_up_alert_table: Clean and finalize cluster alert table:

.clean_up_alert_tableR Documentation

Clean and finalize cluster alert table:

Description

Function takes the raw cluster alert table, and cleans it up, namely removing some columns that are not needed, renaming some columns, and setting the final order of columns

Usage

.clean_up_alert_table(clt)

Arguments

clt

cluster alert table holding the cluster specific information

Value

data.table of cleaned up column names


gsClusterDetect documentation built on July 27, 2026, 5:09 p.m.