| .meters_per_unit | R Documentation |
Function returns the number of meters in unit (one of miles, kilometers, or meters)
.meters_per_unit(unit)
unit |
Character scalar specifying distance unit; one of
|
Numeric scalar conversion factor from the selected unit to meters.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.