dot-numeric_location_coords: Helper function reduces a data frame to only those rows where...

.numeric_location_coordsR Documentation

Helper function reduces a data frame to only those rows where latitude and longitude are not missing

Description

Helper function reduces a data frame to only those rows where latitude and longitude are not missing

Usage

.numeric_location_coords(locs)

Arguments

locs

A data.table with latitude and longitude columns.

Value

data.table filtered to non-missing latitude rows with numeric latitude/longitude columns.


gsClusterDetect documentation built on July 27, 2026, 5:09 p.m.