generate_heatmap_data: Get heat map data from a set of location, date, count data

View source: R/summary_functions.R

generate_heatmap_dataR Documentation

Get heat map data from a set of location, date, count data

Description

Generate heat map data frame count information by date and location given an input frame of count-by-location-and-date data.

Usage

generate_heatmap_data(
  data,
  end_date = NULL,
  locations = NULL,
  baseline_length = 90,
  test_length = 7,
  guard = 0,
  break_points = c(-1, 2, 4, 9, 19, Inf),
  break_labels = c("0-1", "2-4", "5-9", "10-19", "20+")
)

Arguments

data

data frame with (at least) three columns: location, date, count

end_date

date indicating end of test interval; if not provided the last date in 'dt' will be used

locations

a vector of locations to subset the table; if none provided then all locations will be used

baseline_length

numeric (default=90) number of days in baseline interval

test_length

numeric (default=7) number of days in test interval

guard

numeric (default=0) number of days between baseline and test interval

break_points

break points for the discrete groups (default = c(-1,2,4,9,19,Inf))

break_labels

string vector of labels for the groups (default = c("0-1", "2-4", "5-9", "10-19", "20+"))

Value

a data frame of heat map data

Examples

generate_heatmap_data(
  data = example_count_data
)

gsClusterDetect documentation built on July 27, 2026, 5:09 p.m.