get_point_data: Compute representative data points for sf polygons

View source: R/mapping_functions.R

get_point_dataR Documentation

Compute representative data points for sf polygons

Description

Computes one point per input feature for use in plotly hover layers. If the input geometry is longitude/latitude, the point-on-surface operation is performed in a projected CRS and then transformed back to the original CRS.

Usage

get_point_data(x, point_crs = NULL)

Arguments

x

sf object

point_crs

CRS to use when 'x' is longitude/latitude. If NULL, EPSG:3857 is used as a general-purpose fallback.


gsClusterDetect documentation built on July 27, 2026, 5:09 p.m.