gsClusterDetect-package: gsClusterDetect: Utilities for Geo-Spatial Cluster Detection...

gsClusterDetect-packageR Documentation

gsClusterDetect: Utilities for Geo-Spatial Cluster Detection and Significance Classification

Description

Provides utilities for manipulating time series of location-based counts of events to detect geo-spatial clusters. Significance of these clusters is determined using a set of models that classify based on a learned relationship between observed and the log(observed/expected) ratio of counts. The approach implemented here is similar to prospective space-time estimation of clusters using the scan statistic.

Author(s)

Maintainer: Luke C. Mullany luke.mullany@jhuapl.edu

Authors:

See Also

Useful links:


gsClusterDetect documentation built on July 27, 2026, 5:09 p.m.