sf_to_plotly_polygons: Convert sf to plotly polygons

View source: R/mapping_functions.R

sf_to_plotly_polygonsR Documentation

Convert sf to plotly polygons

Description

Helper function that takes the shape file merged with cluster information as returned by the "map_data" element of prepare_map_data() and converts each location to long polygon coordinate rows suitable for plotly.

Usage

sf_to_plotly_polygons(md)

Arguments

md

list as returned by prepare_map_data()

Details

This function only prepares drawing geometry. Hover information is prepared separately in prepare_map_data() as the "hover_data" element.


gsClusterDetect documentation built on July 27, 2026, 5:09 p.m.