validate_sf_file: Validates sf file

View source: R/mapping_functions.R

validate_sf_fileR Documentation

Validates sf file

Description

Function ingests an object and check if this is of class sf, and has an unique identifer for its rows

Usage

validate_sf_file(s, s_id, label_id = NULL)

Arguments

s

shape file; must be of class sf

s_id

string unique identifier of 's'

label_id

string column of 's' that indicates display label for the row in 's' (default is NULL)


gsClusterDetect documentation built on July 27, 2026, 5:09 p.m.