Helper function simply asserts if tigris is installed. It is not required, to run the package in general, but is required for some additional functionality
.assert_tigris_available(fn_name)Invisibly returns NULL; otherwise throws an error when
tigris is unavailable.
Character scalar naming the calling function, used in the error message.