.numeric_location_coords: Helper function reduces a data frame to only those rows where latitude
and longitude are not missing
Description
Helper function reduces a data frame to only those rows where latitude
and longitude are not missing
Usage
.numeric_location_coords(locs)
Value
data.table filtered to non-missing latitude rows with
numeric latitude/longitude columns.
Arguments
- locs
A data.table with latitude and longitude
columns.