locs within threshold_meters of each loc in locs.This is a helper function to create a named list of all the locations in
locs within threshold_meters of each loc in locs.
.sparse_dist_list_from_locs(locs, threshold_meters, meters_per_unit)Named list of numeric vectors of neighbor distances, keyed by location.
A data.table with columns location,
latitude, and longitude.
Numeric scalar distance threshold in meters.
Numeric scalar conversion factor from output unit to meters.