Create a sparse distance list from custom location data
Source:R/location_functions.R
create_custom_dist_list.RdThis function is a custom-data version of create_dist_list(). It
returns a list of named numeric vectors where each list element contains only
locations within threshold distance units of a target location.
Usage
create_custom_dist_list(
df,
label_var,
lat_var,
long_var,
threshold,
unit = c("miles", "kilometers", "meters")
)Arguments
- df
data.frame containing label and coordinate columns
- label_var
character scalar; column name used as location label (must be unique and non-missing)
- lat_var
character scalar; latitude column name.
- long_var
character scalar; longitude column name.
- threshold
numeric scalar distance cutoff in units of
unit- unit
string, one of "miles" (default), "kilometers", or "meters"
Value
a named list, where each element, named by a target location, is a named vector of distances that are within `threshold` `units` of the target.
Examples
# \donttest{
md <- tract_generator("MD")
#>
|
| | 0%
|
|= | 2%
|
|== | 3%
|
|=== | 4%
|
|=== | 5%
|
|==== | 5%
|
|==== | 6%
|
|===== | 7%
|
|===== | 8%
|
|====== | 9%
|
|======= | 10%
|
|======= | 11%
|
|======== | 12%
|
|========= | 13%
|
|========== | 14%
|
|========== | 15%
|
|=========== | 16%
|
|============ | 17%
|
|============= | 18%
|
|============= | 19%
|
|============== | 19%
|
|============== | 20%
|
|=============== | 22%
|
|================ | 22%
|
|================ | 23%
|
|================= | 24%
|
|================== | 25%
|
|================== | 26%
|
|=================== | 28%
|
|==================== | 28%
|
|===================== | 30%
|
|====================== | 31%
|
|======================= | 33%
|
|======================== | 34%
|
|========================== | 37%
|
|=========================== | 39%
|
|============================ | 39%
|
|============================ | 40%
|
|============================= | 42%
|
|============================== | 43%
|
|============================== | 44%
|
|=============================== | 44%
|
|=============================== | 45%
|
|================================ | 45%
|
|================================= | 47%
|
|================================== | 49%
|
|=================================== | 50%
|
|=================================== | 51%
|
|==================================== | 52%
|
|===================================== | 53%
|
|======================================== | 58%
|
|========================================== | 60%
|
|============================================= | 64%
|
|============================================== | 66%
|
|=============================================== | 68%
|
|================================================= | 70%
|
|=================================================== | 72%
|
|=================================================== | 73%
|
|===================================================== | 76%
|
|====================================================== | 77%
|
|====================================================== | 78%
|
|======================================================= | 78%
|
|======================================================= | 79%
|
|======================================================== | 80%
|
|========================================================= | 81%
|
|========================================================== | 83%
|
|============================================================= | 87%
|
|=============================================================== | 90%
|
|================================================================= | 93%
|
|==================================================================== | 97%
|
|==================================================================== | 98%
|
|======================================================================| 100%
dlist <- create_custom_dist_list(
df = md,
label_var = "geoid",
lat_var = "latitude",
long_var = "longitude",
threshold = 15,
unit = "miles"
)
# }