create_custom_dist_list: Create a sparse distance list from custom location data
Description
This function is a custom-data version of create_dist_list(). It
returns a list of named numeric vectors where each list element contains only
locations within threshold distance units of a target location.