| .assert_tigris_available | R Documentation |
Helper function simply asserts if tigris is installed. It is not required, to run the package in general, but is required for some additional functionality
.assert_tigris_available(fn_name)
fn_name |
Character scalar naming the calling function, used in the error message. |
Invisibly returns NULL; otherwise throws an error when
tigris is unavailable.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.