| .clean_up_alert_table | R Documentation |
Function takes the raw cluster alert table, and cleans it up, namely removing some columns that are not needed, renaming some columns, and setting the final order of columns
.clean_up_alert_table(clt)
clt |
cluster alert table holding the cluster specific information |
data.table of cleaned up column names
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.