| .sparse_dist_list_from_locs | R Documentation |
locs within threshold_meters of each loc in locs.This is a helper function to create a named list of all the locations in
locs within threshold_meters of each loc in locs.
.sparse_dist_list_from_locs(locs, threshold_meters, meters_per_unit)
locs |
A |
threshold_meters |
Numeric scalar distance threshold in meters. |
meters_per_unit |
Numeric scalar conversion factor from output unit to meters. |
Named list of numeric vectors of neighbor distances, keyed by location.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.