powered by
Synthetic county-level example count data for package examples and tests. Generation included a synthetic injection of cases near the end of the time series to ensure that clusters are detected in this example dataset.
example_count_data
A data frame with 11,264 rows and 4 columns:
county FIPS code as character
date of observation
non-negative integer daily count