powered by
Generate a ggplot heatmap of count information by date and location given a frame of count-by-location-and-date data.
generate_heatmap(heatmap_data, plot_type = c("ggplot", "plotly"), ...)
a ggplot or plotly object
data frame generated by `generate_heatmap_data`
string indicating either a "ggplot" or "plotly" result. If the requested backend is unavailable, the function warns and falls back to the other backend when available.
passed onto plotly
hd <- generate_heatmap_data(example_count_data) generate_heatmap(hd) generate_heatmap(hd, plot_type = "plotly")
Run the code above in your browser using DataLab