View source: R/cluster_functions.R
| get_baseline_dates | R Documentation |
Function to generate baseline dates given an end date and test length, plus optional guard, and length of baseline
get_baseline_dates(end_date, test_length, baseline_length, guard = 0)
end_date |
End date of the test interval |
test_length |
(integer) length of the test interval in days |
baseline_length |
(integer) length of baseline period in days |
guard |
(integer) default = 0; buffer between end of baseline and start of test interval |
vector of dates
get_baseline_dates(
end_date = "2025-01-01",
test_length = 10,
baseline_length = 90
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.