Learn R Programming

gsClusterDetect (version 1.0.0)

gsClusterDetect-package: gsClusterDetect: Utilities for Geo-Spatial Cluster Detection and Significance Classification

Description

Provides utilities for manipulating time series of location-based counts of events to detect geo-spatial clusters. Significance of these clusters is determined using a set of models that classify based on a learned relationship between observed and the log(observed/expected) ratio of counts. The approach implemented here is similar to prospective space-time estimation of clusters using the scan statistic.

Arguments

Author

Maintainer: Luke Mullany luke.mullany@jhuapl.edu

Authors:

  • Howard Burkom

See Also