Helper function to identify states represented in a location frame; this is helpful because the location functions are faster and more efficient when states are specified.
Usage
identify_states(df, level = c("zip", "county"), location = "location")Helper function to identify states represented in a location frame; this is helpful because the location functions are faster and more efficient when states are specified.
identify_states(df, level = c("zip", "county"), location = "location")