View source: R/cluster_functions.R
| reduce_clusters_to_min | R Documentation |
Function takes a set of clusters identified via compress_clusters()
and a minimum threshold for counts, and reduces the identified clusters to
only those clusters where the total number of observed across the cluster
meets that minimum threshold.
reduce_clusters_to_min(cl, minimum = 0)
cl |
a object of class |
minimum |
numeric (default = 0); minimum number across all locations in a cluster in order to retain |
an object of class clusters
cl <- find_clusters(
cases = example_count_data,
distance_matrix = county_distance_matrix("OH")[["distance_matrix"]],
detect_date = example_count_data[, max(date)],
distance_limit = 50
)
reduce_clusters_to_min(cl, 50)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.