View source: R/mapping_functions.R
| sf_to_plotly_polygons | R Documentation |
Helper function that takes the shape file merged with cluster information
as returned by the "map_data" element of prepare_map_data() and
converts each location to long polygon coordinate rows suitable for plotly.
sf_to_plotly_polygons(md)
md |
list as returned by |
This function only prepares drawing geometry. Hover information is prepared
separately in prepare_map_data() as the "hover_data" element.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.