View source: R/location_functions.R
| state_distance_matrix | R Documentation |
Function returns a list of states and a matrix with the distance between those states. leverages a built in dataset ('states')
state_distance_matrix(unit = c("miles", "kilometers", "meters"))
unit |
string, one of "miles" (default), "kilometers", or "meters". Indicating the desired unit for the distances |
a named list of length two; first element ('loc_vec') is a vector of locations and the second element ('distance_matrix') is a square matrix containing the pairwise distance (in the given 'unit') between all locations.
state_distance_matrix()
state_distance_matrix(unit = "kilometers")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.