Learn R Programming

gsClusterDetect (version 1.0.0)

us_distance_matrix: Get distance matrix for all counties in the US

Description

Function returns a list of counties and a matrix with the distance between those counties. leverages a built in dataset (`counties`). Note that the generation of this matrix can take a few seconds. Note: it is better and faster to use create_dist_list().

Usage

us_distance_matrix(unit = c("miles", "kilometers", "meters"))

Value

a named list of length two; first element (`loc_vec`) is a vector of locations and the second element (`distance_matrix`) is a square matrix containing the pairwise distance (in the given `unit`) between all locations.

Arguments

unit

string, one of "miles" (default), "kilometers", or "meters". Indicating the desired unit for the distances

Examples

Run this code
# \donttest{
# Takes ~ 10 seconds, depending on machine
us_distance_matrix(unit = "kilometers")
# }

Run the code above in your browser using DataLab