View source: R/mapping_functions.R
| validate_sf_file | R Documentation |
Function ingests an object and check if this is of class sf, and has an unique identifer for its rows
validate_sf_file(s, s_id, label_id = NULL)
s |
shape file; must be of class sf |
s_id |
string unique identifier of 's' |
label_id |
string column of 's' that indicates display label for the row in 's' (default is NULL) |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.